@@ -1,6 +1,6 @@
+# -*- coding: UTF-8 -*-
 from datetime import datetime
-from platform import system
-
+from msvcrt import getch
 from multiprocessing import Manager, Process
 from ntpath import exists, join
 from os import listdir, mkdir, remove
@@ -15,11 +15,6 @@ from pyaudio import PyAudio, paInt8, paInt16, paInt24, paInt32
 from pyautogui import screenshot
 from pygame.time import Clock
 
-if system() == 'Windows':
-    from msvcrt import getch
-elif system() in ('Linux', 'Darwin'):
-    from getch import getch
-
 image_cache = []
 pic_files = []
 saving_image_thread_lock = Lock()
@@ -113,7 +108,8 @@ def _save_image(start_event, image_cache, img_temp_dir):
             img_index += 1
             release_lock()
 
-            image.save(f'{img_temp_dir}\{local_index:08x}.jpg', quality=95)
+            image.save('{}\{:08x}.jpg'.format(
+                img_temp_dir, local_index), quality=95)
 
         if saving_image_current_thread not in saving_image_threads_dict:
             break
@@ -138,7 +134,7 @@ def _scan(start_event, init_threads_num, image_cache, max_fps, img_temp_dir):
             saving_image_thread = Thread(target=_save_image,
                                          args=[start_event,
                                                image_cache, img_temp_dir],
-                                         name=f'saving_image_thread{threads_num}')
+                                         name='saving_image_thread{}'.format(threads_num))
             saving_image_thread.start()
             cache_length = len(image_cache)
             threads_num += 1
@@ -162,7 +158,7 @@ def _cue(start_event):
     while start_event_setted():
         if num_of_dots == 4:
             num_of_dots = 0
-        print("\x1b[2J", end='')
+        print("\r\x1B[K", end='')
         print('(按"q"键结束录制)Recording' + num_of_dots * '.', end='')
         num_of_dots += 1
         tick(1)
@@ -181,7 +177,7 @@ def start_screen_recording(record_audio: bool = True,
                            codec: str = 'libx264') -> None:
 
     audio_filename = str(datetime.now())[:19].replace(':', '_') + '.mp3'
-    img_temp_dir = f'.{audio_filename[:-4]}_temp'
+    img_temp_dir = '.{}_temp'.format(audio_filename[:-4])
     video_filename = audio_filename[:-3] + 'mp4'
 
     if exists(img_temp_dir):
@@ -203,14 +199,14 @@ def start_screen_recording(record_audio: bool = True,
                            name='scan_process')
     processes.append(scan_process)
 
-    cue_process = Process(target=_cue, args=[start_event], name='cue_process ')
+    cue_process = Process(target=_cue, args=[start_event], name='cue_process')
     processes.append(cue_process)
 
     strat_process = Process.start
     join_process = Process.join
     [strat_process(process) for process in processes]
 
-    print(f'{delay}秒后开始录制，按"q"键结束录制。')
+    print('{}秒后开始录制，按"q"键结束录制。'.format(delay))
 
     sleep(delay)
     start_event.set()
